// Author: NiuJiuRu
// Email: niujiuru@qq.com
// Date: 2025-07-31
#ifndef __AIR720U_H__
#define __AIR720U_H__

#include "../swapi/include_swapiLib.h"

#ifdef __cplusplus
extern "C"
{
#endif

// 打开与模块的通讯, 返回: 0成功, <0时失败
int Air720U_ComInit();

// 关闭与模块的通讯, 返回: 0成功, <0时失败
int Air720U_ComExit();

// 控制模块断电重启, 返回: 0成功, <0时失败
int Air720U_Repower();

// 获取模块的标识号, 返回: =15成功, <0失败(-1命令超时)
int Air720U_GetIMEI(char buf[16]/*固定长15个十进制数字组成*/);

// 获取网络注册状态, 返回: >=0成功, <0失败(-1命令超时)
int Air720U_GetCregState();

// 获取当前信号强度, 返回: >=0成功, <0失败(-1命令超时)
int Air720U_GetRSSIFromCSQ();

// 返回电话卡的状态, 返回: 1已可用, <0失败(-1命令超时)
int Air720U_IsSimCardReady();

// 获取电话卡标识号, 返回: =20成功, <0失败(-1命令超时)
int Air720U_GetSimICCID(char buf[21]/*一般由20个十进制数字组成*/);

#ifdef __cplusplus
}
#endif

#endif /* __AIR720U_H__ */
